cli

package
v0.0.19 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2025 License: MIT Imports: 12 Imported by: 0

Documentation

Overview

Package cli implements the command-line interface for slot.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute(version string) error

Execute runs the root command for the slot CLI application.

func Init

func Init() *cobra.Command

Init returns the cobra command for generating shell integration scripts.

func List

func List(config *string) *cobra.Command

List returns the cobra command for listing command slots.

func Path added in v0.0.12

func Path(slotsFile *string) *cobra.Command

Path returns the cobra command for displaying the path to the slot store.

func Remove

func Remove(config *string) *cobra.Command

Remove returns the cobra command for removing command slots.

func Render

func Render(config *string) *cobra.Command

Render returns the cobra command for rendering command slots.

func Save

func Save(config *string) *cobra.Command

Save returns the cobra command for saving command slots.

Types

This section is empty.

Jump to