render

package
v0.0.19 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 28, 2025 License: MIT Imports: 5 Imported by: 0

Documentation

Overview

Package render provides Go template parsing and execution for command string substitution.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Apply

func Apply(templateString string, variables map[string]any) (string, error)

Apply executes a Go template with provided variables, returning an error if parsing fails or variables are missing.

Types

This section is empty.

Jump to